function [ants,pco,pce,pcv,els,azs]=readatx(file)
% readatx.m :
% read antex antenna model from file.
%
% argout :
%    ants        = antenna list
%    pco{f}(i,:) = Lf ants{i} phase center offset [e,n,u] (m)
%    pce{f}(i,j) = Lf ants{i} phase center variation at els(j) (m)
%    pcv{f}(j,k,i) = Lf ants{i} phase center variation at azs(j)/els(k) (m)
%    els         = elevation angles (deg)
%    azs         = azimuth angles (deg)
% 
%            Copyright(c) 2007-2011 by T.Takasu, all rights reserved
%
% version: $Revision: 1.1 $ $Date: 2008/06/03 01:26:51 $
% history: 2008/06/02 1.0 new
%          2011/09/13 1.1 support L5

ants={}; pco={[],[],[]}; pce={[],[],[]}; pcv={[],[],[]};
els=0:5:90; azs=0:5:360;

ant=''; frq=[]; az=[]; el=[]; ne=length(els); na=length(azs);
f=fopen(file,'r');
if f<0, disp(['antex file open error : ',file]); return; end
while 1
    s=fgetl(f); if ~isstr(s), break; end
    label=s(60:end);
    if findstr(label,'TYPE / SERIAL NO')
        ant=deblank(s(1:16)); ext=deblank(s(17:32));
        if ~strcmp(ext,'NONE'), ant=[ant,'(',ext,')']; end
        if findstr(ant,'BLOCK'), ant=''; continue; end % gps
        if findstr(ant,'GLONASS'), ant=''; continue; end % glonass
        ants={ants{:},ant}; e0=repmat(nan,1,ne); v0=repmat(nan,na,ne);
        pco{1}=[pco{1};0,0,0]; pce{1}=[pce{1};e0]; pcv{1}=cat(3,pcv{1},v0);
        pco{2}=[pco{2};0,0,0]; pce{2}=[pce{2};e0]; pcv{2}=cat(3,pcv{2},v0);
        pco{3}=[pco{3};0,0,0]; pce{3}=[pce{3};e0]; pcv{3}=cat(3,pcv{3},v0);
    elseif findstr(label,'DAZI');
        v=readrecord(s(4:end));
        if length(v)>=1, az=0:v(1):360; else az=[]; end
    elseif findstr(label,'ZEN1 / ZEN2 / DZEN');
        v=readrecord(s(4:end));
        if length(v)>=3, el=90-(v(1):v(3):v(2)); else el=[]; end
    elseif findstr(label,'END OF ANTENNA'), ant='';
    elseif findstr(label,'START OF FREQUENCY')
        v=sscanf(s(4:6),'G%d');
        if v==1|v==2, frq=v; elseif v==5, frq=3; else frq=[]; end
    elseif findstr(label,'END OF FREQUENCY'), frq=[];
    elseif isempty(frq), continue;
    elseif isempty(ant), continue;
    elseif findstr(label,'NORTH / EAST / UP')
        v=readrecord(s(4:end));
        if length(v)<3|isempty(frq), continue; end
        pco{frq}(end,:)=v([2,1,3])'*1E-3;
    elseif findstr(s(4:end),'NOAZI')
        v=readrecord(s(9:end));
        if length(v)~=length(el)|isempty(frq), continue; end
        [e,i,j]=intersect(els,el);
        pce{frq}(end,i)=v(j)'*1E-3;
    else
        v=readrecord(s(4:end));
        if length(v)~=length(el)+1, continue; end
        k=find(azs==v(1)); if isempty(k)|isempty(frq), continue; end
        [e,i,j]=intersect(els,el); v=v(2:end);
        pcv{frq}(k,i,end)=v(j)'*1E-3;
    end
end
fclose(f);

% read records -----------------------------------------------------------------
function v=readrecord(s)
v=sscanf(s,'%f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f');
