function [pos,E]=togeod(ru)
% togeod.m :
% transform ecef position ru=[x;y;z] (m) to geodetic position pos=[lat,lon,h]
% (rad/m) and compute local tangental coordinate transformation matrix E.
%
%            Copyright(c) 2007-2008 by T.Takasu, all rights reserved
%
% version: $Revision: 1.3 $ $Date: 2008/06/03 01:26:51 $
% history: 2008/06/02 1.0 new

R=6378137; F=1/298.257223563; e2=F*(2-F); % WGS84

if norm(ru)<=0, pos=[0,0,0]; E=eye(3); return, end
r=norm(ru(1:2)); z=ru(3);
for i=1:10
    a=z/sqrt(r^2+z^2);
    n=R/sqrt(1-e2*a^2);
    zp=ru(3)+n*e2*a;
    if abs(zp-z)<1E-4, break; else z=zp; end
end
if abs(a)<1E-12, h=r-R; else h=zp/a-n; end
pos=[atan(zp/r),atan2(ru(2),ru(1)),h];
sinp=sin(pos(1));
cosp=cos(pos(1));
sinl=ru(2)/r;
cosl=ru(1)/r;
E=[-sinl,cosl,0;-sinp*cosl,-sinp*sinl,cosp;cosp*cosl,cosp*sinl,sinp];
